powered by
Calculates the daily environmental costs of flow regulation
daily_cost(First_year, Last_year, Year_evaluated, Year_impact, a_low, a_high, b_low, b_high)
First year to consider in the analysis starting on October 1st (e.g.: First_year = 1964)
First year to consider in the analysis finishing on September 30th (e.g.: Last_year = 2011)
Year when the environmental impact is evaluated (e.g.: Year_evaluated = 2010)
Year when the human impact started (the construction of a dam) (e.g.: Year_impact = 1988)
Coefficient a of Low-flow impact of function ku (e.g.: a_low = 0.05)
Coefficient a of High-flow impact of function ku (e.g.: a_high = 0.01)
Coefficient b of Low-flow impact of function ku (e.g.: b_low = 2)
Coefficient b of High-flow impact of function ku (e.g.: b_high = 2)
Calculates the daily environmental costs of flow regulation for a specific year evaluated.
# NOT RUN { data(flowdata) daily_cost(First_year=1964, Last_year=2011,Year_evaluated=2010, Year_impact=1988, a_low = 0.05, a_high = 0.01, b_low = 2, b_high = 2) # }
Run the code above in your browser using DataLab